@@ -5,9 +5,9 @@
 #'     e.g. "DRKS00005219". (A capitalized "DRKS" followed by eight
 #'     numerals with no spaces or hyphens.)
 #'
-#' @return A vector of ISO-8601 formatted dates corresponding to the
-#'     dates on which there were clinical trial history version
-#'     updates.
+#' @return A character vector of ISO-8601 formatted dates
+#'     corresponding to the dates on which there were clinical trial
+#'     history version updates.
 #'
 #' @export
 #'
@@ -23,21 +23,43 @@ drks_de_dates <- function(drksid) {
 
     out <- tryCatch({
 
+        ## Check that TRN is well-formed
+        if (! grepl("^DRKS\\d{8}$", drksid)) {
+            stop(paste0("'", drksid, "' is not a well-formed TRN"))
+        }
+
         url <- paste0(
             "https://drks.de/drks_web/navigate.do?",
             "navigationId=trial.history&TRIAL_ID=",
             drksid
         )
 
-        index <- rvest::read_html(url)
+        session <- polite::bow(url)
 
-        index %>%
+        index <- polite::scrape(session)
+
+        ## Back up locale info
+        lct <- Sys.getlocale("LC_TIME")
+        ## Set locale so that months are parsed correctly on
+        ## non-English computers
+        Sys.setlocale("LC_TIME", "C")
+
+        dates <- index %>%
             rvest::html_nodes("tr:not(.bgHighlight) > td:nth-child(1)") %>%
             rvest::html_text() %>%
             as.Date(format = "%m-%d-%Y") %>%
             sort() %>%
-            format("%Y-%m-%d") %>%
-            return()
+            format("%Y-%m-%d")
+
+        ## Restore original locale info
+        Sys.setlocale("LC_TIME", lct)
+
+        ## Check for NA values in dates
+        if (sum(is.na(dates)) > 0) {
+            warning("NA values returned for dates")
+        }
+        
+        return(dates)
 
     },
     error = function(cond) {
