@@ -4,7 +4,7 @@ test_that("DRKS.de history entries mass-download correctly", {
         file.remove(filename)
     }
     result <- drks_de_download(
-        c("DRKS00005219", "DRKS00015220"), filename
+        c("DRKS00003961"), filename, TRUE
     )
     expect_equal(
         result == TRUE || result == FALSE,
